@@ -72,6 +72,55 @@ this submodule rather than from :mod:`typing` directly: e.g.,
    from beartype.typing import Tuple, List, Dict, Set, FrozenSet, Type
 '''
 
+# ....................{ TODO                               }....................
+#FIXME: Fundamentally generalize this submodule to optionally backport
+#attributes from "typing_extensions" where available, resolving issue #237 at:
+#    https://github.com/beartype/beartype/issues/237
+#
+#To do so, we'll basically want to discard the entire current implementation of
+#this submodule in favour of a fundamentally superior approach resembling:
+#    # In "beartype.typing.__init__": the future of typing backports begins today.
+#    from typing import TYPE_CHECKING
+#
+#    # If @beartype is currently being statically type-checked (e.g.,
+#    # by mypy or pyright), just defer to the third-party
+#    # "typing_extensions" package.
+#    #
+#    # Note that this does *NOT* mean that @beartype now unconditionally
+#    # requires "typing_extensions" at either runtime or static
+#    # type-checking time. Any code in an "if TYPE_CHECKING:" is (basically)
+#    # just a convincing semantic lie that everything syntactically ignores.
+#    if TYPE_CHECKING:
+#        from typing_extensions import *  # <-- heh
+#    # Else, @beartype is currently being imported from at runtime. This is
+#    # the common case. This is also the non-trivial case, because @beartype
+#    # does *NOT* require "typing_extensions" as a mandatory runtime
+#    # dependency, because @beartype requires *NOTHING* as a runtime
+#    # dependency. This is the only rule in @beartype's Rule of Law.
+#    else:
+#        #FIXME: Unfortunately, to avoid circular import dependencies, these
+#        #imports will need to be copy-and-pasted into equivalent condensed
+#        #submodules of a new "beartype.typing._util" subpackage.
+#        # Import the requisite machinery that will make the magic happen.
+#        from beartype._util.hint.utilhintfactory import TypeHintTypeFactory
+#        from beartype._util.module.lib.utiltyping import (
+#            import_typing_attr_or_fallback as _import_typing_attr_or_fallback)
+#
+#        # Dynamically define the "Self" type hint as follows:
+#        # * If the active Python interpreter targets Python >= 3.11, just
+#        #   defer to the canonical "typing.Self" type hint.
+#        # * Else if "typing_extensions" is importable *AND* of a sufficiently
+#        #   recent version to define the backported "typing_extensions.Self"
+#        #   type hint, fallback to that hint.
+#        # * Else, synthesize a placeholder type hint that @beartype internally
+#        #   recognizes as semantically equivalent to "typing.Self".
+#        Self = _import_typing_attr_or_fallback('Self', object)
+#        LiteralString = _import_typing_attr_or_fallback('Self', str)
+#        TypeGuard = _import_typing_attr_or_fallback('Self', bool)
+#        Annotated = _import_typing_attr_or_fallback('Annotated', bool)
+#
+#        #FIXME: Repeat the above logic for *ALL* existing "typing" attributes.
+
 # ....................{ IMPORTS                            }....................
 #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 # WARNING: To avoid polluting the public module namespace, external attributes
@@ -85,11 +134,9 @@ this submodule rather than from :mod:`typing` directly: e.g.,
 # "import_typing_attr_or_none('Annotated')").
 #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 from beartype._util.py.utilpyversion import (
-    IS_PYTHON_AT_LEAST_3_11  as _IS_PYTHON_AT_LEAST_3_11,
-    IS_PYTHON_AT_LEAST_3_10  as _IS_PYTHON_AT_LEAST_3_10,
-    IS_PYTHON_AT_LEAST_3_9   as _IS_PYTHON_AT_LEAST_3_9,
-    IS_PYTHON_AT_LEAST_3_8   as _IS_PYTHON_AT_LEAST_3_8,
-    IS_PYTHON_AT_LEAST_3_7_2 as _IS_PYTHON_AT_LEAST_3_7_2,
+    IS_PYTHON_AT_LEAST_3_11 as _IS_PYTHON_AT_LEAST_3_11,
+    IS_PYTHON_AT_LEAST_3_10 as _IS_PYTHON_AT_LEAST_3_10,
+    IS_PYTHON_AT_LEAST_3_9  as _IS_PYTHON_AT_LEAST_3_9,
 )
 
 # ....................{ IMPORTS ~ all                      }....................
@@ -111,24 +158,30 @@ from typing import (
     TYPE_CHECKING as TYPE_CHECKING,
     Any as Any,
     AnyStr as AnyStr,
-    NewType as NewType,
-    Text as Text,
     BinaryIO as BinaryIO,
     ClassVar as ClassVar,
+    Final as Final,  # pyright: ignore[reportGeneralTypeIssues]
     ForwardRef as ForwardRef,
     Generic as Generic,
     Hashable as Hashable,
     IO as IO,
-    Match as Match,
+    Literal as Literal,  # pyright: ignore[reportGeneralTypeIssues]
+    NewType as NewType,
     NamedTuple as NamedTuple,
     NoReturn as NoReturn,
     Optional as Optional,
-    Pattern as Pattern,
+    Reversible as Reversible,  # pyright: ignore[reportGeneralTypeIssues]
     Sized as Sized,
+    SupportsIndex as SupportsIndex,  # pyright: ignore[reportGeneralTypeIssues]
+    TypedDict as TypedDict,  # pyright: ignore[reportGeneralTypeIssues]
+    Text as Text,
     TextIO as TextIO,
     TypeVar as TypeVar,
     Union as Union,
     cast as cast,
+    final as final,  # pyright: ignore[reportGeneralTypeIssues]
+    get_args as get_args,  # pyright: ignore[reportGeneralTypeIssues]
+    get_origin as get_origin,  # pyright: ignore[reportGeneralTypeIssues]
     get_type_hints as get_type_hints,
     no_type_check as no_type_check,
     no_type_check_decorator as no_type_check_decorator,
@@ -162,88 +215,67 @@ from typing import (
 #* Submitting an upstream issue requesting that mypy respect the
 #  "# type: ignore[attr-defined]" pragma rather than emitting warnings here.
 
-# If the active Python interpreter targets Python >= 3.8...
-if _IS_PYTHON_AT_LEAST_3_8:
+# If the active Python interpreter targets Python >= 3.10...
+if _IS_PYTHON_AT_LEAST_3_10:
     from typing import (  # type: ignore[attr-defined]
-        Final as Final,  # pyright: ignore[reportGeneralTypeIssues]
-        Literal as Literal,  # pyright: ignore[reportGeneralTypeIssues]
-        Reversible as Reversible,  # pyright: ignore[reportGeneralTypeIssues]
-        SupportsIndex as SupportsIndex,  # pyright: ignore[reportGeneralTypeIssues]
-        TypedDict as TypedDict,  # pyright: ignore[reportGeneralTypeIssues]
-        final as final,  # pyright: ignore[reportGeneralTypeIssues]
-        get_args as get_args,  # pyright: ignore[reportGeneralTypeIssues]
-        get_origin as get_origin,  # pyright: ignore[reportGeneralTypeIssues]
+        Concatenate as Concatenate,  # pyright: ignore[reportGeneralTypeIssues]
+        ParamSpec as ParamSpec,  # pyright: ignore[reportGeneralTypeIssues]
+        ParamSpecArgs as ParamSpecArgs,  # pyright: ignore[reportGeneralTypeIssues]
+        ParamSpecKwargs as ParamSpecKwargs,  # pyright: ignore[reportGeneralTypeIssues]
+        TypeAlias as TypeAlias,  # pyright: ignore[reportGeneralTypeIssues]
+        TypeGuard as TypeGuard,  # pyright: ignore[reportGeneralTypeIssues]
+        is_typeddict as is_typeddict,  # pyright: ignore[reportGeneralTypeIssues]
     )
 
-    # If the active Python interpreter targets Python >= 3.10...
-    if _IS_PYTHON_AT_LEAST_3_10:
+    # If the active Python interpreter targets Python >= 3.11...
+    if _IS_PYTHON_AT_LEAST_3_11:
         from typing import (  # type: ignore[attr-defined]
-            Concatenate as Concatenate,  # pyright: ignore[reportGeneralTypeIssues]
-            ParamSpec as ParamSpec,  # pyright: ignore[reportGeneralTypeIssues]
-            ParamSpecArgs as ParamSpecArgs,  # pyright: ignore[reportGeneralTypeIssues]
-            ParamSpecKwargs as ParamSpecKwargs,  # pyright: ignore[reportGeneralTypeIssues]
-            TypeAlias as TypeAlias,  # pyright: ignore[reportGeneralTypeIssues]
-            TypeGuard as TypeGuard,  # pyright: ignore[reportGeneralTypeIssues]
-            is_typeddict as is_typeddict,  # pyright: ignore[reportGeneralTypeIssues]
+               LiteralString as LiteralString,  # pyright: ignore[reportGeneralTypeIssues]
+               Never as Never,  # pyright: ignore[reportGeneralTypeIssues]
+               NotRequired as NotRequired,  # pyright: ignore[reportGeneralTypeIssues]
+               Required as Required,  # pyright: ignore[reportGeneralTypeIssues]
+               Self as Self,  # pyright: ignore[reportGeneralTypeIssues]
+               TypeVarTuple as TypeVarTuple,  # pyright: ignore[reportGeneralTypeIssues]
+               Unpack as Unpack,  # pyright: ignore[reportGeneralTypeIssues]
+               assert_never as assert_never,  # pyright: ignore[reportGeneralTypeIssues]
+               assert_type as assert_type,  # pyright: ignore[reportGeneralTypeIssues]
+               clear_overloads as clear_overloads,  # pyright: ignore[reportGeneralTypeIssues]
+               dataclass_transform as dataclass_transform,  # pyright: ignore[reportGeneralTypeIssues]
+               reveal_type as reveal_type,  # pyright: ignore[reportGeneralTypeIssues]
+               get_overloads as get_overloads,  # pyright: ignore[reportGeneralTypeIssues]
+               reveal_type as reveal_type,  # pyright: ignore[reportGeneralTypeIssues]
         )
 
-        # If the active Python interpreter targets Python >= 3.11...
-        if _IS_PYTHON_AT_LEAST_3_11:
-            from typing import (  # type: ignore[attr-defined]
-                   LiteralString as LiteralString,  # pyright: ignore[reportGeneralTypeIssues]
-                   Never as Never,  # pyright: ignore[reportGeneralTypeIssues]
-                   NotRequired as NotRequired,  # pyright: ignore[reportGeneralTypeIssues]
-                   Required as Required,  # pyright: ignore[reportGeneralTypeIssues]
-                   Self as Self,  # pyright: ignore[reportGeneralTypeIssues]
-                   TypeVarTuple as TypeVarTuple,  # pyright: ignore[reportGeneralTypeIssues]
-                   Unpack as Unpack,  # pyright: ignore[reportGeneralTypeIssues]
-                   assert_never as assert_never,  # pyright: ignore[reportGeneralTypeIssues]
-                   assert_type as assert_type,  # pyright: ignore[reportGeneralTypeIssues]
-                   clear_overloads as clear_overloads,  # pyright: ignore[reportGeneralTypeIssues]
-                   dataclass_transform as dataclass_transform,  # pyright: ignore[reportGeneralTypeIssues]
-                   reveal_type as reveal_type,  # pyright: ignore[reportGeneralTypeIssues]
-                   get_overloads as get_overloads,  # pyright: ignore[reportGeneralTypeIssues]
-                   reveal_type as reveal_type,  # pyright: ignore[reportGeneralTypeIssues]
-            )
-
 # ....................{ PEP ~ 544                          }....................
-# If this interpreter is either performing static type-checking (e.g., via mypy)
-# *OR* targets Python < 3.8, defer to the standard library versions of the
-# family of "Supports*" protocols available under Python < 3.8.
-if TYPE_CHECKING or not _IS_PYTHON_AT_LEAST_3_8:
+# If this interpreter is performing static type-checking (e.g., via mypy), defer
+# to the standard library versions of the family of "Supports*" protocols
+# available under Python < 3.8.
+if TYPE_CHECKING:
     from typing import (  # type: ignore[attr-defined]
+        Protocol as Protocol,  # pyright: ignore[reportGeneralTypeIssues]
         SupportsAbs as SupportsAbs,
         SupportsBytes as SupportsBytes,
         SupportsComplex as SupportsComplex,
         SupportsFloat as SupportsFloat,
+        SupportsIndex as SupportsIndex,  # pyright: ignore[reportGeneralTypeIssues]
         SupportsInt as SupportsInt,
         SupportsRound as SupportsRound,
+        runtime_checkable as runtime_checkable,  # pyright: ignore[reportGeneralTypeIssues]
+    )
+# Else, this interpreter is *NOT* performing static type-checking. In this
+# case, prefer our optimized PEP 544 attributes.
+else:
+    from beartype.typing._typingpep544 import (
+        Protocol as Protocol,
+        SupportsAbs as SupportsAbs,
+        SupportsBytes as SupportsBytes,
+        SupportsComplex as SupportsComplex,
+        SupportsFloat as SupportsFloat,
+        SupportsIndex as SupportsIndex,
+        SupportsInt as SupportsInt,
+        SupportsRound as SupportsRound,
+        runtime_checkable as runtime_checkable,
     )
-
-# If this interpreter targets Python >= 3.8 and thus fully supports PEP 544...
-if _IS_PYTHON_AT_LEAST_3_8:
-    # If this interpreter is performing static type-checking, defer to the
-    # standard library versions of all remaining PEP 544 attributes.
-    if TYPE_CHECKING:
-        from typing import (  # type: ignore[attr-defined]
-            Protocol as Protocol,  # pyright: ignore[reportGeneralTypeIssues]
-            SupportsIndex as SupportsIndex,  # pyright: ignore[reportGeneralTypeIssues]
-            runtime_checkable as runtime_checkable,  # pyright: ignore[reportGeneralTypeIssues]
-        )
-    # Else, this interpreter is *NOT* performing static type-checking. In this
-    # case, prefer our optimized PEP 544 attributes.
-    else:
-        from beartype.typing._typingpep544 import (
-            Protocol as Protocol,
-            SupportsAbs as SupportsAbs,
-            SupportsBytes as SupportsBytes,
-            SupportsComplex as SupportsComplex,
-            SupportsFloat as SupportsFloat,
-            SupportsIndex as SupportsIndex,
-            SupportsInt as SupportsInt,
-            SupportsRound as SupportsRound,
-            runtime_checkable as runtime_checkable,
-        )
 
 # ....................{ PEP ~ 585                          }....................
 # If this interpreter is either performing static type-checking (e.g., via mypy)
@@ -283,10 +315,13 @@ if TYPE_CHECKING or not _IS_PYTHON_AT_LEAST_3_9:
         KeysView as KeysView,
         List as List,
         Mapping as Mapping,
+        Match as Match,
         MappingView as MappingView,
         MutableMapping as MutableMapping,
         MutableSequence as MutableSequence,
         MutableSet as MutableSet,
+        OrderedDict as OrderedDict,
+        Pattern as Pattern,
         Reversible as Reversible,
         Set as Set,
         Tuple as Tuple,
@@ -294,14 +329,6 @@ if TYPE_CHECKING or not _IS_PYTHON_AT_LEAST_3_9:
         Sequence as Sequence,
         ValuesView as ValuesView,
     )
-
-    # If the active Python interpreter targets Python >= 3.7.2, import *ALL*
-    # public attributes of the "typing" module introduced by Python 3.7.2
-    # deprecated by PEP 585 as their original values.
-    if _IS_PYTHON_AT_LEAST_3_7_2:
-        from typing import (  # type: ignore[attr-defined]
-            OrderedDict as OrderedDict,
-        )
 # If the active Python interpreter targets Python >= 3.9 and thus supports PEP
 # 585, alias *ALL* public attributes of the "typing" module deprecated by PEP
 # 585 to their equivalent values elsewhere in the standard library.
@@ -342,6 +369,10 @@ else:
         AbstractContextManager as ContextManager,
         AbstractAsyncContextManager as AsyncContextManager,
     )
+    from re import (
+        Match as Match,
+        Pattern as Pattern,
+    )
     from typing import (  # type: ignore[attr-defined]
         Annotated,
     )
