@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2022 Beartype authors.
+# Copyright (c) 2014-2023 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -20,7 +20,7 @@ from beartype.vale._util._valeutilsnip import (
     VALE_CODE_CHECK_ISSUBCLASS_TEST_format,
 )
 from beartype.vale._core._valecore import BeartypeValidator
-from beartype._data.datatyping import (
+from beartype._data.hint.datahinttyping import (
     LexicalScope,
     TypeOrTupleTypes,
 )
