@@ -8,7 +8,7 @@ Project-wide :pep:`593`-compliant **type hint test data.**
 '''
 
 # ....................{ IMPORTS                            }....................
-from beartype_test._util.mod.pytmodtyping import is_typing_attrs
+from beartype_test._util.module.pytmodtyping import is_typing_attrs
 
 # ....................{ ADDERS                             }....................
 def add_data(data_module: 'ModuleType') -> None:
@@ -50,7 +50,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HintSignAnnotated,
         HintSignList,
     )
-    from beartype._util.mod.lib.utiltyping import iter_typing_attrs
+    from beartype._util.module.lib.utiltyping import iter_typing_attrs
     from beartype_test.a00_unit.data.data_type import (
         Class,
         Subclass,
